# -*- coding: utf-8 -*-
# Moovida - Home multimedia server
# Copyright (C) 2006-2009 Fluendo Embedded S.L. (www.fluendo.com).
# All rights reserved.
#
# This file is available under one of two license agreements.
#
# This file is licensed under the GPL version 3.
# See "LICENSE.GPL" in the root of this distribution including a special
# exception to use Moovida with Fluendo's plugins.
#
# The GPL part of Moovida is also available under a commercial licensing
# agreement from Fluendo.
# See "LICENSE.Moovida" in the root directory of this distribution package
# for details on that license.
#
# Author: Philippe Normand <philippe@fluendo.com>

from elisa.core.utils import defer
from elisa.core.utils.i18n import install_translation

from elisa.plugins.poblesec.actions import Action, LinkAction
from elisa.plugins.poblesec.actions import GoToNode, GoToAction, \
                                           ActionNodesNotSetError

from elisa.plugins.flickr.utils import get_flickr_provider


_ = install_translation('flickr')
_poblesec = install_translation('poblesec')


class PicturesGoToAction(GoToAction):
    """ This action will clear the poblesec history, goto the pictures
    menu and proceed with other goto nodes same way L{GoToAction}
    does.
    """

    def run(self):
        if not self.nodes:
            raise ActionNodesNotSetError()

        browser = self.controller.frontend.retrieve_controllers('/poblesec/browser')[0]
        browser.history.clear()

        # Select the pictures item in Elisa's main menu
        for i, link in enumerate(browser.history.current.model):
            if link.controller_path == '/poblesec/pictures_menu':
                browser.history.current.menu.selected_item_index = i
                break

        def _append_controller(result, *args, **kwargs):
            return browser.history.append_controller(*args, **kwargs)

        dfr = defer.succeed(True)
        for node in self.nodes:
            dfr.addCallback(_append_controller, node.path, node.title, **node.args)

        return dfr


class LoginAction(LinkAction):
    """ L{LinkAction} leading to the Flickr login form.
    """

    title = _('Login to Flickr')
    path = '/poblesec/flickr/login'
    icon = 'elisa.plugins.poblesec.key_icon'


class LogoutAction(Action):
    """ Action used to clear the Flickr resource_provider
    authentication token and go back to the previous menu. This action
    is called from the 'My Account' menu.
    """

    title = _('Logout From Flickr')
    icon = 'elisa.plugins.poblesec.remove'

    def run(self):
        get_flickr_provider().logout()

        frontend = self.controller.frontend
        browser = frontend.retrieve_controllers('/poblesec/browser')[0]
        return browser.history.go_back()


class MyAccountAction(LinkAction):
    """ Action leading to the 'My Account' menu.
    """
    icon = 'elisa.plugins.poblesec.user_account'
    title = _('My Flickr Account')
    path = '/poblesec/flickr/account'
